@@ -570,7 +570,9 @@ test_token_item_remove (Test *test, gconstpointer unused)
 int
 main (int argc, char **argv)
 {
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	g_test_init (&argc, &argv, NULL);
 
 	g_test_add ("/secret-store/collection/is_locked", Test, NULL, setup, test_is_locked, teardown);
